@@ -11,6 +11,7 @@ from typing import Tuple
 from mcipc.config import LOG_FORMAT, InvalidCredentials, Credentials
 from mcipc.rcon.config import CONFIG
 from mcipc.rcon.datastructures import Players
+from mcipc.rcon.exceptions import RequestIdMismatch, WrongPassword
 from mcipc.rcon.playground import Client
 
 
@@ -26,7 +27,8 @@ def get_args() -> Namespace:
     parser = ArgumentParser(description='A Minecraft RCON client.')
     parser.add_argument('server', help='the server to connect to')
     parser.add_argument(
-        '-t', '--timeout', type=float, help='connection timeout in seconds')
+        '-t', '--timeout', type=float, metavar='seconds',
+        help='connection timeout in seconds')
     parser.add_argument(
         '-d', '--debug', action='store_true',
         help='print additional debug information')
@@ -51,7 +53,8 @@ def get_args() -> Namespace:
         'datetime',
         help='sends the current date and time to the players on the server')
     datetime_parser.add_argument(
-        '-f', '--format', default='%c', help='the datetime format')
+        '-f', '--format', default='%c', metavar='format_string',
+        help='the datetime format')
     subparsers.add_parser('in-use', help='checks whether the server is in use')
     shutdown_parser = subparsers.add_parser(
         'idle-shutdown', help='shuts down the server if it is not in use')
@@ -59,7 +62,7 @@ def get_args() -> Namespace:
         '-s', '--sudo', action='store_true',
         help='invoke the shutdown command using sudo')
     shutdown_parser.add_argument(
-        '-u', '--unit', default='minecraft@{server}.service',
+        '-u', '--unit', default='minecraft@{server}.service', metavar='unit',
         help='the systemd unit template')
     return parser.parse_args()
 
@@ -147,18 +150,19 @@ def main():
 
     try:
         with Client(host, port, timeout=args.timeout) as client:
-            if not client.login(passwd):
-                LOGGER.error('Failed to log in.')
-                exit(4)
+            client.login(passwd)
 
             if args.action == 'idle-shutdown':
-                players = client.players
+                if not idle_shutdown(client.players, args):
+                    exit(1)
             else:
                 run_action(client, args)
     except timeout:
         LOGGER.error('Connection timeout.')
-        exit(3)
-
-    if args.action == 'idle-shutdown':
-        if not idle_shutdown(players, args):
-            exit(1)
+        exit(4)
+    except RequestIdMismatch:
+        LOGGER.error('Unexpected request ID mismatch.')
+        exit(5)
+    except WrongPassword:
+        LOGGER.error('Wrong password.')
+        exit(6)
