@@ -20,7 +20,8 @@ def get_args() -> Namespace:
 
     parser = ArgumentParser(description='An interactive RCON shell.')
     parser.add_argument('server', nargs='?', help='the server to connect to')
-    parser.add_argument('-p', '--prompt', default=PS1, help='the shell prompt')
+    parser.add_argument('-p', '--prompt', default=PS1, metavar='PS1',
+                        help='the shell prompt')
     return parser.parse_args()
 
 
