@@ -4,8 +4,9 @@ from __future__ import annotations
 from typing import NamedTuple
 
 from mcipc.query.proto.common import MAGIC
-from mcipc.query.proto.common import random_session_id
+from mcipc.query.proto.common import decodeall
 from mcipc.query.proto.common import ip_or_hostname
+from mcipc.query.proto.common import BigEndianSignedInt32
 from mcipc.query.proto.common import IPAddressOrHostname
 from mcipc.query.proto.common import Type
 
@@ -18,24 +19,25 @@ class Request(NamedTuple):
 
     magic: bytes
     type: Type
-    session_id: int
-    challenge_token: int
+    session_id: BigEndianSignedInt32
+    challenge_token: BigEndianSignedInt32
 
     def __bytes__(self):
         """Returns the packet as bytes."""
         payload = self.magic
         payload += bytes(self.type)
-        payload += self.session_id.to_bytes(4, 'big', signed=True)
-        payload += self.challenge_token.to_bytes(4, 'big', signed=True)
+        payload += bytes(self.session_id)
+        payload += bytes(self.challenge_token)
         return payload
 
     @classmethod
-    def create(cls, challenge_token: int, session_id: int = None) -> Request:
+    def create(cls, challenge_token: BigEndianSignedInt32,
+               session_id: BigEndianSignedInt32 = None) -> Request:
         """Creates a new request with the specified challenge
         token and the specified or a random session ID.
         """
         if session_id is None:
-            session_id = random_session_id()
+            session_id = BigEndianSignedInt32.random_session_id()
 
         return cls(MAGIC, Type.STAT, session_id, challenge_token)
 
@@ -44,7 +46,7 @@ class BasicStats(NamedTuple):
     """Basic statistics response packet."""
 
     type: Type
-    session_id: int
+    session_id: BigEndianSignedInt32
     motd: str
     game_type: str
     map: str
@@ -57,11 +59,9 @@ class BasicStats(NamedTuple):
     def from_bytes(cls, bytes_: bytes) -> BasicStats:   # pylint: disable=R0914
         """Creates the packet from the respective bytes."""
         type_ = Type.from_bytes(bytes_[0:1])
-        session_id = int.from_bytes(bytes_[1:5], 'big', signed=True)
-        motd, *blocks, port_ip, _ = bytes_[5:].split(b'\0')
-        motd = motd.decode('latin-1')
-        strings = [block.decode('latin-1') for block in blocks]
-        game_type, map_, num_players, max_players = strings
+        session_id = BigEndianSignedInt32.from_bytes(bytes_[1:5])
+        *blocks, port_ip, _ = bytes_[5:].split(b'\0')
+        motd, game_type, map_, num_players, max_players = decodeall(blocks)
         num_players = int(num_players)
         max_players = int(max_players)
         host_port = int.from_bytes(port_ip[0:2], 'little')
