@@ -2,15 +2,17 @@
 
 from __future__ import annotations
 from enum import Enum
+from functools import partial
 from ipaddress import ip_address, IPv4Address, IPv6Address
 from random import randint
-from typing import Union
+from typing import Iterable, Iterator, Union
 
 
 __all__ = [
     'MAGIC',
-    'random_session_id',
+    'decodeall',
     'ip_or_hostname',
+    'BigEndianSignedInt32',
     'IPAddressOrHostname',
     'Type'
 ]
@@ -21,12 +23,10 @@ SESSION_ID_MASK = 0x0F0F0F0F
 IPAddressOrHostname = Union[IPv4Address, IPv6Address, str]
 
 
-def random_session_id() -> int:
-    """Returns a random session ID.
-    See: https://wiki.vg/Query#Generating_a_Session_ID
-    """
+def decodeall(blocks: Iterable[bytes], encoding='latin-1') -> Iterator[str]:
+    """Decodes all byte blocks with the given encoding."""
 
-    return randint(-2147483648, 2147483647 + 1) & SESSION_ID_MASK
+    return map(partial(bytes.decode, encoding=encoding), blocks)
 
 
 def ip_or_hostname(string: str) -> IPAddressOrHostname:
@@ -38,6 +38,29 @@ def ip_or_hostname(string: str) -> IPAddressOrHostname:
         return string
 
 
+class BigEndianSignedInt32(int):
+    """A big-endian, signed int32."""
+
+    MIN = -2_147_483_648
+    MAX = 2_147_483_647
+
+    def __bytes__(self):
+        """Returns the int as bytes."""
+        return self.to_bytes(4, 'big', signed=True)
+
+    @classmethod
+    def from_bytes(cls, bytes_: bytes) -> BigEndianSignedInt32:
+        """Reutns the int from the given bytes."""
+        return super().from_bytes(bytes_, 'big', signed=True)
+
+    @classmethod
+    def random_session_id(cls) -> BigEndianSignedInt32:
+        """Returns a random session ID.
+        See: https://wiki.vg/Query#Generating_a_Session_ID
+        """
+        return cls(randint(cls.MIN, cls.MAX) & SESSION_ID_MASK)
+
+
 class Type(Enum):
     """Request type."""
 
