@@ -37,9 +37,9 @@ class StubServer:
         self.protocol = protocol
 
     @property
-    def slp_response(self) -> SLPResponse:
-        """Returns an SLP response."""
-        json = {
+    def slp_content(self) -> dict:
+        """Returns the content of an SLP response."""
+        return {
             'version': {
                 'name': self.version,
                 'protocol': self.protocol
@@ -52,12 +52,16 @@ class StubServer:
                 'text': self.description
             }
         }
-        return SLPResponse(VarInt(0), json)
+
+    @property
+    def slp_response(self) -> SLPResponse:
+        """Returns an SLP response."""
+        return SLPResponse(VarInt(0), self.slp_content)
 
     @staticmethod
     def _perform_handshake(connection: socket) -> State:
         """Handle handshake requests."""
-        handshake = Handshake.read(connection.recv)
+        handshake = Handshake.from_socket(connection)
         LOGGER.debug('Got handshake: %s', handshake)
         return handshake.next_state
 
@@ -77,8 +81,8 @@ class StubServer:
 
     def _handle_login(self, connection: socket):
         """Performs a login."""
-        size = VarInt.read(connection.recv)
-        packet_id = VarInt.read(connection.recv)
+        size = VarInt.from_socket(connection)
+        packet_id = VarInt.from_socket(connection)
         packet_id_length = len(bytes(packet_id))
         payload = connection.recv(size - packet_id_length)
         LOGGER.debug('Got packet ID: %s', packet_id)
